import { Injectable, Inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';

import { _MODULE_CONFIG } from '../config/token';
import { ModuleConfig } from '../config/module-config';
import { Urls } from '../config/urls';
import { UrlConfig, WindowUtil } from '@ucap-webmessenger/core';
import { NGXLogger } from 'ngx-logger';
import {
  ConferenceJoinRequest,
  encodeConferenceJoin
} from '../apis/conference-join';
import { NativeService, UCAP_NATIVE_SERVICE } from '@ucap-webmessenger/native';
import {
  encodeConferenceCreate,
  ConferenceCreateRequest
} from '../apis/conference-create';

@Injectable({
  providedIn: 'root'
})
export class ConferenceService {
  readonly urls: Urls;

  constructor(
    @Inject(_MODULE_CONFIG) private moduleConfig: ModuleConfig,
    @Inject(UCAP_NATIVE_SERVICE) private nativeService: NativeService,
    private httpClient: HttpClient,
    private logger: NGXLogger
  ) {
    this.urls = UrlConfig.getUrls(
      this.moduleConfig.hostConfig,
      this.moduleConfig.urls
    );
  }

  public conferenceCreate(req: ConferenceCreateRequest): void {
    let url = this.urls.conferenceCreate;
    url = url + `?${encodeConferenceCreate(req).toString()}`;
    // WindowUtil.popupOpen(url, 'DaesangConfJoin', 685, 640);
    this.nativeService.openDefaultBrowser(url);
  }

  public conferencejoin(req: ConferenceJoinRequest): void {
    let url = this.urls.conferenceJoin;
    url = url + `?${encodeConferenceJoin(req).toString()}`;
    // WindowUtil.popupOpen(url, 'DaesangConfJoin', 685, 640);
    this.nativeService.openDefaultBrowser(url);
  }
}
